.. todo:: THIS IS SUPPOSED TO BE AN EXAMPLE. MODIFY IT ACCORDING TO YOUR NEEDS!

   The document assumes you are using a source repository service that promotes a
   contribution model similar to `GitHub's fork and pull request workflow`_.
   While this is true for the majority of services (like GitHub, GitLab,
   BitBucket), it might not be the case for private repositories (e.g., when
   using Gerrit).

   Also notice that the code examples might refer to GitHub URLs or the text
   might use GitHub specific terminology (e.g., *Pull Request* instead of *Merge
   Request*).

   Please make sure to check the document having these assumptions in mind
   and update things accordingly.

.. todo:: Provide the correct links/replacements at the bottom of the document.

.. todo:: You might want to have a look on `PyScaffold's contributor's guide`_,

   especially if your project is open source. The text should be very similar to
   this template, but there are a few extra contents that you might decide to
   also include, like mentioning labels of your issue tracker or automated
   releases.


============
Contributing
============

Welcome to ``moosir_feature`` contributor's guide.

This document focuses on getting any potential contributor familiarized
with the development processes, but `other kinds of contributions`_ are also
appreciated.

If you are new to using git_ or have never collaborated in a project previously,
please have a look at `contribution-guide.org`_. Other resources are also
listed in the excellent `guide created by FreeCodeCamp`_ [#contrib1]_.

Please notice, all users and contributors are expected to be **open,
considerate, reasonable, and respectful**. When in doubt, `Python Software
Foundation's Code of Conduct`_ is a good reference in terms of behavior
guidelines.


Issue Reports
=============



Documentation Improvements
==========================




Code Contributions
==================

